Changes
=======

Unreleased
----------

Version 0.2.0
-------------

Released 2021-10-24

- Refine app.config name for PasetoLoginManager. `#16 <https://github.com/dajiaji/python-cwt/pull/16>`__
- Add tests for PasetoLoginManager. `#16 <https://github.com/dajiaji/python-cwt/pull/16>`__
- Rename package name from Flask PASETO Extended to flask-paseto-extended. `#15 <https://github.com/dajiaji/python-cwt/pull/15>`__
- Add tests for PasetoCookieSessionInterface. `#14 <https://github.com/dajiaji/python-cwt/pull/14>`__

Version 0.1.1
-------------

Released 2021-10-23

- Activate Read the Docs. `#12 <https://github.com/dajiaji/python-cwt/pull/12>`__

Version 0.1.0
-------------

Released 2021-10-23

- First public release. `#11 <https://github.com/dajiaji/python-cwt/pull/11>`__
